"use client";
import React, { useState } from "react";
import * as Yup from "yup";
// Chakra imports
import {
  Box,
  Button,
  Flex,
  FormControl,
  Heading,
  Text,
  useColorModeValue,
  PinInput,
  PinInputField,
} from "@chakra-ui/react";

// Custom components
import DefaultAuthLayout from "@/layouts/auth/Default";
import Form from "@/components/form/Form";

// Assets
import Link from "next/link";
import { useRouter } from "next/navigation";
import { VerifyOtp } from "@/app/lib/actions/auth.actions";
import useShowToast from "@/app/hooks/useShowToast";

const validationSchema = Yup.object().shape({});

export default function ForgotPage() {
  // Chakra color mode
  const textColor = useColorModeValue("navy.700.700", "white");
  const textGray = useColorModeValue("gray.700", "white");
  const textColorSecondary = "gray.400";
  const textColorDetails = useColorModeValue("navy.700", "secondaryGray.600");
  const textColorBrand = useColorModeValue("brand.500", "white");

  // sign in logic
  const showToast = useShowToast();
  const [otp, setOtp] = useState("");
  const [loading, setLoading] = useState(false);
  // Destructure formDetails
  const router = useRouter();

  const handleSubmit = async () => {
    setLoading(true);
    try {
      await VerifyOtp({
        otp,
        reset_token: localStorage.getItem("reset_token"),
      });
      showToast("OTP verified", "Otp verified succuessfully!", "success");
      router.push("/auth/reset-password");
    } catch (error: any) {
      showToast("Verification failed!", error.message, "error");
    } finally {
      setLoading(false);
    }
  };

  const signInText = "Enter the OTP sent to your email";
  const handleChange = (value: any) => {
    setOtp(value);
  };

  return (
    <DefaultAuthLayout illustrationBackground={"/img/auth/medianet_logo.png"}>
      <Flex
        maxW={{ base: "100%", md: "max-content" }}
        w="100%"
        mx={{ base: "auto", lg: "0px" }}
        me="auto"
        h="100%"
        alignItems="start"
        justifyContent="center"
        mb={{ base: "30px", md: "30px" }}
        px={{ base: "25px", md: "0px" }}
        mt={{ base: "40px", md: "4vh" }}
        flexDirection="column"
      >
        <Box me="auto">
          <Heading color={textColor} fontSize="36px" mb="10px">
            OTP
          </Heading>
          <Text
            mb="36px"
            ms="4px"
            color={textColorSecondary}
            fontWeight="400"
            fontSize="md"
          >
            {signInText}
          </Text>
        </Box>
        <Flex
          zIndex="2"
          direction="column"
          w={{ base: "100%", md: "420px" }}
          maxW="100%"
          background="transparent"
          borderRadius="15px"
          mx={{ base: "auto", lg: "unset" }}
          me="auto"
          mb={{ base: "20px", md: "auto" }}
        >
          <Form
            validationSchema={validationSchema}
            initialValues={{}}
            submitForm={() => {
              handleSubmit();
            }}
          >
            <FormControl w="full">
              <Flex justifyContent={"center"} gap={2} my="24px">
                <PinInput otp onChange={handleChange}>
                  {[...Array(4)].map((_, index) => (
                    <PinInputField
                      key={index}
                      placeholder="0"
                      fontWeight="500"
                      textColor={textGray}
                      mb="2px"
                    />
                  ))}
                </PinInput>
              </Flex>
              <Button
                fontSize="sm"
                type="submit"
                variant="brand"
                fontWeight="500"
                w="100%"
                h="50"
                mb="24px"
                isLoading={loading}
                loadingText="Submitting..."
                isDisabled={loading || otp.length < 4}
              >
                Submit
              </Button>
            </FormControl>
          </Form>
          <Flex
            flexDirection="column"
            justifyContent="center"
            alignItems="start"
            maxW="100%"
            mt="0px"
          >
            <Link href="/auth/signin">
              <Text color={textColorDetails} fontWeight="400" fontSize="14px">
                Already have an account?
                <Text
                  color={textColorBrand}
                  as="span"
                  ms="5px"
                  fontWeight="500"
                >
                  Login
                </Text>
              </Text>
            </Link>
          </Flex>
        </Flex>
      </Flex>
    </DefaultAuthLayout>
  );
}
